/* Balsa E-Mail Client
 * Copyright (C) 1997-1999 Jay Painter and Stuart Parmenter
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2, or (at your option)
 * any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA
 * 02111-1307, USA.
 */
#ifndef __pref_manager_h__
#define __pref_manager_h__


/* open the preferences manager window */
void open_preferences_manager (GtkWidget *widget, gpointer data);

/* refresh any data displayed in the preferences manager
 * window in case it has changed */
void refresh_preferences_manager (void);

/* update the pop3 server clist */
void update_pop3_servers (void);

#endif
/* __pref_manager_h__ */
